@@ -1,6 +1,6 @@
 use utf8;
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.162360';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.163570';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
@@ -258,7 +258,7 @@ sub mk_dxcontrol{
 		my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
 		my $id = delete($attrs->{id});
 		if (my $name = $id) {
-			$attrs->{attr}{name}=$name;
+			$attrs->{inputAttr}{name}=$name;
 		}
 		
 		$id //= new_id( $c, $attrs );
@@ -391,7 +391,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.162360
+version 0.163570
 
 =head1 SUBROUTINES/METHODS
 
